@@ -1,7 +1,8 @@
 /*
- * @(#)$Id: link.h,v 61.2 1998/10/29 19:30:58 jleffler Exp $ 
+ * @(#)$Id: link.h,v 2003.1 2003/01/14 23:52:40 jleffler Exp $
  *
- * Copyright (c) 1998 Jonathan Leffler
+ * Copyright 1998    Jonathan Leffler
+ * Copyright 2002-03 IBM
  *
  * You may distribute under the terms of either the GNU General Public
  * License or the Artistic License, as specified in the Perl README file.
@@ -20,11 +21,6 @@ struct Link
 	void	*data;
 };
 
-#define dbd_ix_link_add		dbd_ix_link_add
-#define dbd_ix_link_delete		dbd_ix_link_delete
-#define dbd_ix_link_newhead	dbd_ix_link_newhead
-#define dbd_ix_link_delchain	dbd_ix_link_delchain
-
 extern void dbd_ix_link_add(Link *link_1, Link *link_n);
 extern void dbd_ix_link_delete(Link *link_d, void (*function)(void *));
 extern void dbd_ix_link_delchain(Link *head, void (*function)(void *));
